AppCallablesSuper class

Constructors

AppCallablesSuper()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getAppInfo() Map<String, dynamic>
getMainScreenElements() Map<String, dynamic>
getMenuCallables() Map<String, dynamic>
getStorage() → FlutterSecureStorage
getThemeParams() Map<String, dynamic>
getUserCallbacks(BuildContext context, dynamic userData) Map<String, dynamic>
mainScreenWidget() Widget
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
runRedirectMainScreen(BuildContext context) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited