CrudEditorState class
- Inheritance
-
- Object
- State<
CrudEditor> - CrudEditorState
Constructors
Properties
-
apiResponse
↔ Map<
String, dynamic> -
getter/setter pair
-
callbacks
↔ Map<
String, dynamic> -
getter/setter pair
- colsForListingLine1 ↔ int
-
getter/setter pair
- colsForListingLine2 ↔ int
-
getter/setter pair
-
constants
↔ Map<
String, dynamic> -
getter/setter pair
- context → BuildContext
-
The location in the tree where this widget builds.
no setterinherited
-
currentUserData
↔ Map<
String, dynamic> -
getter/setter pair
-
editorConfig
↔ Map<
String, dynamic> -
getter/setter pair
- errorCode ↔ String
-
getter/setter pair
- errorMessage ↔ String
-
getter/setter pair
- errorWaitForOk ↔ bool
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- ignoreUserData ↔ bool
-
getter/setter pair
- infoMessage ↔ String
-
getter/setter pair
- isCreation ↔ bool
-
getter/setter pair
- isCreationForced ↔ bool
-
getter/setter pair
- isEditMode ↔ bool
-
getter/setter pair
- isEditModeForced ↔ bool
-
getter/setter pair
- itemIdForced ↔ String
-
getter/setter pair
- items ↔ List
-
getter/setter pair
- listingFieldElements ↔ List
-
getter/setter pair
- mounted → bool
-
Whether this State object is currently in a tree.
no setterinherited
-
originalSelectedItem
↔ Map<
String, dynamic> -
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
searchFilters
↔ Map<
String, dynamic> -
getter/setter pair
- selectedItem ↔ dynamic
-
getter/setter pair
- showAppMenu ↔ bool
-
getter/setter pair
- storage → FlutterSecureStorage
-
final
- urlGenSuffix ↔ String
-
getter/setter pair
- userId ↔ String
-
getter/setter pair
- widget → CrudEditor
-
The current configuration.
no setterinherited
Methods
-
activate(
) → void -
Called when this object is reinserted into the tree after having been
removed via deactivate.
inherited
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
canonicalRow(
dynamic row) → String -
deactivate(
) → void -
Called when this object is removed from the tree.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
didChangeDependencies(
) → void -
Called when a dependency of this State object changes.
inherited
-
didUpdateWidget(
covariant CrudEditor oldWidget) → void -
Called whenever the widget configuration changes.
override
-
dispose(
) → void -
Called when this object is removed from the tree permanently.
inherited
-
initState(
) → void -
Called when this object is inserted into the tree.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
reassemble(
) → void -
Called whenever the application is reassembled during debugging, for
example during hot reload.
inherited
-
rowId(
dynamic row, bool isCreation) → String -
setState(
VoidCallback fn) → void -
Notify the framework that the internal state of this object has changed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringShort(
) → String -
A brief description of this object, usually just the runtimeType and the
hashCode.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited