HttpUtilities class

Constructors

HttpUtilities()

Properties

configItems Map<String, dynamic>
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
jwtToken String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

httpsCall(String requestType, String apiUrl, Map<String, dynamic> customHeaders, Map<String, dynamic> bodyParams, Map<String, dynamic> getParams, {bool useServerLog = true}) Future<Map<String, dynamic>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited